# Generated by roxygen2: do not edit by hand

export(add_snapshot_context)
export(as_character)
export(as_value_key)
export(classify_operational_file_type)
export(compile_rulebook)
export(construct_structural_paths)
export(context_roots)
export(coverage_roots)
export(coverage_rules_path)
export(derive_record_set)
export(derive_structural_groups)
export(detect_generated_artifacts)
export(exclude_operational_noise)
export(invert_contextual_grouping)
export(invert_value_key)
export(is.prelabelled)
export(observe_universe)
export(observe_wacz)
export(prelabel)
export(quick_signature)
export(quick_signature_text)
export(read_snapshot)
export(recordset_df)
export(refine)
export(refine_by_rulebook)
export(save_scan)
export(scan_storage)
export(snapshot_storage)
export(snapshot_to_reconstruction_context)
export(snapshot_to_recordset_df)
export(subset_snapshot)
export(summarise_duplicates)
export(summarise_observed_activity)
export(summarize_duplicates)
export(summarize_observed_activity)
export(wacz_to_recordset_df)
importFrom(dataset,"provenance<-")
importFrom(dataset,as_character)
importFrom(dataset,as_dataset_df)
importFrom(dataset,as_value_key)
importFrom(dataset,defined)
importFrom(dataset,dublincore)
importFrom(dataset,identifier)
importFrom(dataset,invert_value_key)
importFrom(dataset,is.prelabelled)
importFrom(dataset,n_triple)
importFrom(dataset,n_triples)
importFrom(dataset,prelabel)
importFrom(dataset,provenance)
importFrom(dataset,subject)
importFrom(dataset,subject_create)
importFrom(digest,digest)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,cross_join)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,group_split)
importFrom(dplyr,if_else)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,n_distinct)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,semi_join)
importFrom(dplyr,slice_head)
importFrom(dplyr,summarise)
importFrom(fs,dir_create)
importFrom(fs,dir_exists)
importFrom(fs,file_info)
importFrom(fs,path)
importFrom(fs,path_abs)
importFrom(fs,path_ext)
importFrom(fs,path_file)
importFrom(fs,path_rel)
importFrom(glue,glue)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,read_json)
importFrom(jsonlite,stream_in)
importFrom(labelled,labelled)
importFrom(magrittr,"%>%")
importFrom(purrr,imap_dfr)
importFrom(purrr,map)
importFrom(purrr,map2_chr)
importFrom(purrr,map_chr)
importFrom(purrr,map_dfr)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
importFrom(purrr,reduce)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,as_name)
importFrom(rlang,enquo)
importFrom(stats,setNames)
importFrom(stringr,fixed)
importFrom(stringr,str_detect)
importFrom(stringr,str_ends)
importFrom(stringr,str_starts)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unnest)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,flush.console)
importFrom(utils,globalVariables)
importFrom(utils,head)
importFrom(utils,person)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(utils,unzip)
