% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/label_country_data.R
\name{label_country_data}
\alias{label_country_data}
\title{Add semantic labels to a data frame column}
\usage{
label_country_data(df, prelabel_map)
}
\arguments{
\item{df}{A data frame.}

\item{prelabel_map}{A named character vector containing
label mappings.}
}
\value{
A data frame with a labelled \code{country} variable.
}
\description{
A minimal example wrapper around \code{dataset::prelabel()}
used in \code{fscontextdemo} to demonstrate semantic enrichment
workflows and provenance-aware data transformations.
}
\examples{
country_map <- c(
  "Andorra" = "AD",
  "Liechtenstein" = "LI",
  "San Marino" = "SM"
)

label_country_data(
  fsdemo_country_data,
  prelabel_map = country_map
)

}
